@@ -12,7 +12,11 @@ class PListSerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(PListSerializer, self).__init__()
+        super(PListSerializer, self).__init__(
+            extensions=[
+                "plist",
+            ],
+        )
 
     def decode(self, s, **kwargs):
         kwargs.setdefault("fmt", plistlib.FMT_XML)
